@@ -4,9 +4,9 @@ from matplotlib import pyplot
 
 
 class ReportFigure:
-    def __init__(self, img_path=None, title=None, description=None, tag=None):
+    def __init__(self, img_path=None, title='', description='', tag=''):
         self.img_path = img_path
-        self.title = title
+        self.title = title.replace(' ', '_')
         self.description = description
         self.tag = tag
 
@@ -18,7 +18,7 @@ class ReportFigure:
 
     @staticmethod
     def of(name: str, report_directory: str, plot: pyplot):
-        report_figure = ReportFigure()
+        report_figure = ReportFigure(title=name)
         fig_rel_path = os.path.join('figures', f'{name}.png')
         fig_path = os.path.join(report_directory, fig_rel_path)
 
